import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import { arc, pie, scaleBand, scaleLinear, max, format } from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Ticks } from './Ticks';

const width = 960;
const height = 500;
const margin = {
  top: 20,
  bottom: 60,
  right: 20,
  left: 200,
};

const innerHeight = height - margin.top - margin.bottom;
const innerWidth = width - margin.left - margin.right;
const xAxisOffset = 50;

const xValue = d => d.Population
const yValue = d => d.Country

const App = () => {
  const data = useData();

  if (!data) {
    return <pre>Loading...</pre>;
  }
  console.log(data[0]);

  const xScale = scaleLinear()
    .domain([0, max(data, (d) => d.Population)])
    .range([0, innerWidth]);

  console.log('ticks ' + xScale.ticks());

  const yScale = scaleBand()
    .domain(data.map((d) => d.Country))
    .range([0, innerHeight])
  	.paddingInner(0.2)
  ;

  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left}, ${margin.top})`}
      >
        <AxisBottom
          xScale={xScale}
          innerHeight={innerHeight}
          tickFormat={n => format(".2s")(n).replace("G", "B")}
        />
        <AxisLeft yScale={yScale} />
        <text x={innerWidth /2} y={innerHeight + xAxisOffset} textAnchor="middle" className="axis-label">Population</text>
        <Ticks
          data={data}
          yScale={yScale}
          xScale={xScale}
          yValue={yValue}
          xValue={xValue}
          tickFormat={n => format(".2s")(n).replace("G", "B")}
          
        />
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
